PythonResultTracker
===================

.. currentmodule:: pykeen.trackers

.. autoclass:: PythonResultTracker
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PythonResultTracker.log_metrics
      ~PythonResultTracker.log_params
      ~PythonResultTracker.start_run

   .. rubric:: Methods Documentation

   .. automethod:: log_metrics
   .. automethod:: log_params
   .. automethod:: start_run
